package com.winhc.bigdata.spark.ng.jobs

import com.winhc.bigdata.spark.ng.utils.explode_args

/**
 * @author: XuJiakai
 * @date: 2021/1/14 19:21
 */
case class args_company_job(tableName: String
                            , md5_fields: Seq[String] //该维度的核心字段
                            , rowkey_add_company_id: Boolean = true //如果存在company_id,是否将company_id作为rowkey前辍
                            , rowkey_udf: String = null //用于自定义rowkey的结构，会覆盖md5_fields的默认rowkey
                            , is_super_filter: Boolean = true //是否开启超级过滤,超级过滤后任一主键都不允许为空
                            , where: String = "" // ods层数据的过滤条件
                            , id_user_defined_rowkey: Boolean = false //是否读取ods层的用户自定义rowkey
                            , verify_company_id: Boolean = true
                            , explode_args: Seq[explode_args] = null //如果表需要炸开，则配制此项
                           )

object args_company_job {
  val tab_md5_fields = Seq(
    args_company_job("company_app_info", Seq("name"))
    , args_company_job("company_staff", Seq("staff_name"))
    , args_company_job("company_holder", Seq("holder_name"), rowkey_udf = "concat_ws('_',company_id,md5(cleanup(concat_ws('',holder_switch_rowkey(holder_type,holder_id,holder_name)))))", where = " holder_name is not null and trim(holder_name) <> '' AND ( not (holder_type = 2 AND length(holder_id) <> 32)) ")
    , args_company_job("company_icp", Seq("liscense", "domain"))
    , args_company_job("company_tm", Seq("reg_no")
      , rowkey_udf = "md5(trim(reg_no))"
      , where = "reg_no is not null and trim(reg_no) <> '' "
      , is_super_filter = false
    )

    , args_company_job("company_court_open_announcement", Seq("case_no", "start_date")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,split_date(cast(start_date as String)) )))"
      , is_super_filter = false
      , where = "is_json_str(defendant_info) and is_json_str(plaintiff_info) and is_json_str(litigant_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )

    , args_company_job("company_dishonest_info", Seq("case_no", "name")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,name )))"
      , is_super_filter = false
      , where = "case_no_trim(case_no) is not null and name is not null"
    )
    , args_company_job("company_zxr_restrict", Seq("case_no", "person_name", "company_name")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,person_name,company_name )))"
      , is_super_filter = false
      , verify_company_id = false
      , where = "case_no_trim(case_no) is not null and person_name is not null and length(trim(person_name))>=2 "
    )

    , args_company_job("company_equity_info", Seq("reg_number", "pledgee_info", "pledgor_info", "related_company_name")
      , rowkey_udf = "md5(cleanup(concat_ws('',reg_number,equity_info_rowkey(pledgee_info,pledgor_info),related_company_name  )))"
      , is_super_filter = false

      , explode_args = Seq(
        explode_args("pledgor_info", "$.pledgor_id", "pledgor_keyno_explode")
        , explode_args("pledgee_info", "$.pledgee_id", "pledgee_keyno_explode")
      )

    )
    , args_company_job("company_land_mortgage", Seq("land_mark", "land_num", "other_item_num", "use_right_num")
      , is_super_filter = false
    )

    , args_company_job("company_judicial_assistance", Seq("executed_person", "execute_notice_num", "type_state", "company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',executed_person,execute_notice_num,type_state,company_id )))"
      , is_super_filter = false
      , verify_company_id = false
    )
    , args_company_job("company_public_announcement", Seq("bill_num")
      , rowkey_add_company_id = false
      , verify_company_id = false
    )

    , args_company_job("company_abnormal_info", Seq("company_id", "put_reason", "put_date")
      , rowkey_udf = "concat_ws('_',company_id,md5(cleanup(concat_ws('',put_reason,split_date(cast(put_date as String)) ))))"
      , is_super_filter = false
    )
    , args_company_job("company_illegal_info", Seq("company_id", "put_reason", "put_date")
      , rowkey_udf = "concat_ws('_',company_id,md5(cleanup(concat_ws('',put_reason,split_date(cast(put_date as String)) ))))"
      , is_super_filter = false
    )

    , args_company_job("zxr_evaluate_results", Seq("case_no", "asset_name", "name", "publish_time")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,asset_name,name,publish_time )))"
      , is_super_filter = false
    )
    , args_company_job("zxr_evaluate", Seq("case_no", "asset_name", "name")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,asset_name,name )))"
      , is_super_filter = false
    )

    , args_company_job("restrictions_on_exit", Seq("case_no", "limited_person", "executed_person_name", "publish_time")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,limited_person,executed_person_name,publish_time )))"
      , is_super_filter = false
    )


    , args_company_job("company_court_announcement", Seq("case_no", "announcement_type", "publish_date", "court_name", "bltn_no")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,announcement_type,split_date(cast(publish_date as String)),court_name,bltn_no )))"
      , is_super_filter = false
      , where = "is_json_str(plaintiff_info) and is_json_str(litigant_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("litigant_info", "$.litigant_id", "litigant_info_id_explode")
      )
    )
    , args_company_job("company_send_announcement", Seq("court", "start_date", "title")
      , rowkey_udf = "md5(cleanup(concat_ws('',court,split_date(cast(start_date as String)),title )))"
      , is_super_filter = false
      , where = "is_json_str(litigant_info) and is_json_str(defendant_info) and is_json_str(plaintiff_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )
    , args_company_job("company_court_register", Seq("case_no", "filing_date")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,split_date(cast(filing_date as String)) )))"
      , is_super_filter = false
      , where = "is_json_str(litigant_info) and is_json_str(defendant_info) and is_json_str(plaintiff_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )
    , args_company_job("company_zxr_final_case", Seq("case_no,name")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,name )))"
      , is_super_filter = false
    )
    , args_company_job("company_tax_contravention", Seq("case_info", "company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_info,company_id )))"
      , is_super_filter = false
    )
    , args_company_job("company_own_tax", Seq("tax_balance", "tax_category", "company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',tax_balance,tax_category,company_id )))"
      , is_super_filter = false
    )
    , args_company_job("company_check_info", Seq("check_type", "check_result", "check_org", "check_date", "company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',check_type,check_result,check_org,split_date(cast(check_date as String)),company_id )))"
      , is_super_filter = false
    )
    , args_company_job("company_mortgage_info", Seq("reg_num")
      , rowkey_udf = "md5(cleanup(concat_ws('',reg_num )))"
      , is_super_filter = false
      , id_user_defined_rowkey = true
    )
    , args_company_job("company_mortgage_pawn", Seq("main_id", "pawn_name", "detail")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',pawn_name,detail ))) )"
      , is_super_filter = false
    )
    , args_company_job("company_mortgage_change", Seq("main_id", "change_date", "change_content")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',split_date(cast(change_date as String)),change_content ))) )"
      , is_super_filter = false
    )
    , args_company_job("company_mortgage_people", Seq("main_id")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id))) )"
      , is_super_filter = false
    )
    , args_company_job("company_double_random_check_info", Seq("check_task_num", "check_plan_num")
      , rowkey_udf = "md5(cleanup(concat_ws('',check_task_num,check_plan_num)))"
      , is_super_filter = false
      , id_user_defined_rowkey = true
    )
    , args_company_job("company_double_random_check_result_info", Seq("main_id", "check_item", "check_result")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',check_item,check_result))) )"
      , is_super_filter = false
    )


    , args_company_job("company_zxr", Seq("name", "case_no")
      , rowkey_udf = "md5(cleanup(concat_ws('',name,case_no)))"
      , is_super_filter = false
    )

    , args_company_job("bankruptcy_open_case", Seq("applicant", "respondent", "public_date", "case_no")
      , rowkey_udf = "md5(cleanup(concat_ws('', applicant, respondent, case_no, (cast(public_date as String)))))"
      , id_user_defined_rowkey = true

      , is_super_filter = false
      , where = "is_json_str(applicant_info) and is_json_str(respondent_info) "
      , explode_args = Seq(
        explode_args("applicant_info", "$.litigant_id", "applicant_info_id_explode")
        , explode_args("respondent_info", "$.litigant_id", "respondent_info_id_explode")
      )

    )

    , args_company_job("bankruptcy_open_announcement", Seq("title", "case_no")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',title,case_no))) )"

      , is_super_filter = false
    )

    , args_company_job("bankruptcy_judgment_document", Seq("title", "case_no")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',title,case_no))) )"

      , is_super_filter = false
    )

    , args_company_job("auction_tracking", Seq("auction_items_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',auction_items_id)))"
      , is_super_filter = false
      , where = "is_json_str(company_info) "
      , explode_args = Seq(
        explode_args("company_info", "$.company_id", "company_info_id_explode")

      )
    )

    , args_company_job("company_punishment_info", Seq("company_name", "punish_number")
      , rowkey_udf = "md5(cleanup(concat_ws('',company_name, punish_number)))"
      , is_super_filter = false
    )

    , args_company_job("company_punishment_info_creditchina", Seq("company_name", "punish_number")
      , rowkey_udf = "md5(cleanup(concat_ws('',company_name, punish_number)))"
      , is_super_filter = false
    )

    , args_company_job("company_brief_cancel_announcement", Seq("company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',company_id)))"
      , id_user_defined_rowkey = true
      , is_super_filter = false
    )

    , args_company_job("company_brief_cancel_announcement_objection", Seq("main_id", "objection_date", "objection_content")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, split_date(cast(objection_date as String)), objection_content))) )"
      , is_super_filter = false
    )

    , args_company_job("company_brief_cancel_announcement_result", Seq("main_id", "announcement_apply_date", "brief_cancel_result")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, split_date(cast(announcement_apply_date as String)), brief_cancel_result))) )"
      , is_super_filter = false
    )

    , args_company_job("company_lawsuit", Seq("case_no", "title")
      , rowkey_udf = "md5(cleanup(concat_ws('', case_no, title)))"
      , is_super_filter = false
      , where = "is_json_str(litigant_info) and is_json_str(defendant_info) and is_json_str(plaintiff_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )

    , args_company_job("company_equity_pledge", Seq("stock_code", "transaction_date", "pledged_num")
      , rowkey_udf = "md5(cleanup(concat_ws('',stock_code, split_date(cast(transaction_date as String)), pledged_num  )))"
      , is_super_filter = false
      , verify_company_id = false
    )

    , args_company_job("company_equity_pledge_holder", Seq("scode", "holder_name", "pledgee", "sharefrozennum", "ndate")
      , rowkey_udf = "md5(cleanup(concat_ws('',scode, holder_name, pledgee, sharefrozennum, split_date(cast(ndate as String))  )))"
      , is_super_filter = false
      , verify_company_id = false
    )

    , args_company_job("company_env_punishment", Seq("name", "punish_number")
      , rowkey_udf = "md5(cleanup(concat_ws('', name, punish_number)))"
      , is_super_filter = false
    )

    , args_company_job("company_liquidating_info", Seq("company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id)))"
      , is_super_filter = false
    )

    , args_company_job("finance_info_v3", Seq("company_id", "year")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, year)))"
      , is_super_filter = false
    )

    , args_company_job("private_enterprise", Seq("company_id", "year")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, year)))"
      , is_super_filter = false
    )


    , args_company_job("company_finance", Seq("company_id", "round")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, round)))"
      , is_super_filter = false
    )


    , args_company_job("company_ipr_pledge", Seq("ipr_reg_num", "pledgee_info", "pledgor_info", "related_company_name")
      , rowkey_udf = "md5(cleanup(concat_ws('', ipr_reg_num, equity_info_rowkey(pledgee_info, pledgor_info), related_company_name  )))"
      , is_super_filter = false

      , explode_args = Seq(
        explode_args("pledgor_info", "$.pledgor_id", "pledgor_keyno_explode")
        , explode_args("pledgee_info", "$.pledgee_id", "pledgee_keyno_explode")
      )

    )


    , args_company_job("company_copyright_reg", Seq("reg_num")
      , rowkey_udf = "md5(cleanup(concat_ws('', reg_num)))"
      , is_super_filter = false
      , explode_args = Seq(
        explode_args("author_nationality_info", "$.keyno", "author_nationality_info_keyno_explode")
      )
    )

    , args_company_job("company_copyright_works", Seq("reg_num")
      , rowkey_udf = "md5(cleanup(concat_ws('', reg_num)))"
      , is_super_filter = false
      , explode_args = Seq(
        explode_args("author_info", "$.keyno", "author_info_keyno_explode")
      )
    )


    , args_company_job("company_patent", Seq("app_number", "pub_number", "applicant_name_info")
      , rowkey_udf = "md5(cleanup(concat_ws('', SUBSTR(app_number, 3), SUBSTR(pub_number, 3), get_text_from_json(applicant_name_info, 'name'))))"
      , is_super_filter = false
      , explode_args = Seq(
        explode_args("applicant_name_info", "$.keyno", "applicant_name_info_keyno_explode")
      )
    )

    , args_company_job("company_certificate", Seq("company_name", "type")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, type)))"
      , is_super_filter = false
    )
    //    , args_company_job("company_icp", Seq("company_name", "domain", "web_baxh")
    //      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, domain, web_baxh)))"
    //      , is_super_filter = false
    //    )
    , args_company_job("company_weibo", Seq("company_name", "name")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, name)))"
      , is_super_filter = false
    )
    , args_company_job("company_customs_credit", Seq("company_name", "record_date")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, split_date(cast(record_date as String)))))"
      , id_user_defined_rowkey = true
      , is_super_filter = false
    )

    , args_company_job("company_customs_credit_administrative_penalty", Seq("main_id", "decision_number", "penalty_date")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, split_date(cast(penalty_date as String)), decision_number))) )"
      , is_super_filter = false
    )

    , args_company_job("company_customs_credit_rating", Seq("main_id", "identification_time", "authentication_code")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, split_date(cast(identification_time as String)), authentication_code))) )"
      , is_super_filter = false
    )

    , args_company_job("company_license", Seq("company_name", "license_number")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, license_number)))"
      , is_super_filter = false
    )

    , args_company_job("company_license_creditchina", Seq("company_name", "licence_number")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, licence_number)))"
      , is_super_filter = false
    )

    , args_company_job("company_license_entpub", Seq("company_name", "license_number")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, license_number)))"
      , is_super_filter = false
    )

    , args_company_job("company_tax", Seq("company_name", "year")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, year)))"
      , is_super_filter = false
    )


    , args_company_job("company_land_announcement", Seq("e_number", "project_name")
      , rowkey_udf = "md5(cleanup(concat_ws('',  e_number, project_name)))"
      , is_super_filter = false
    )

    , args_company_job("company_land_publicity", Seq("title", "project_name")
      , rowkey_udf = "md5(cleanup(concat_ws('', title, project_name)))"
      , is_super_filter = false
    )

    , args_company_job("company_land_transfer", Seq("num", "location")
      , rowkey_udf = "md5(cleanup(concat_ws('', num, location)))"
      , is_super_filter = false
    )

    , args_company_job("company_bond", Seq("publisher_name", "bond_name", "bond_num")
      , rowkey_udf = "md5(cleanup(concat_ws('', publisher_name, bond_name, bond_num)))"
      , is_super_filter = false
    )

    , args_company_job("company_tele_license", Seq("company_name", "license_number")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, license_number)))"
      , id_user_defined_rowkey = true
      , is_super_filter = false
    )

    , args_company_job("company_tele_license_annual_report", Seq("main_id")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id))) )"
      , is_super_filter = false
    )

    , args_company_job("company_tele_license_communication_badness", Seq("main_id", "deal_time")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, split_date(cast(deal_time as String))))) )"
      , is_super_filter = false
    )

    , args_company_job("company_change", Seq("company_id", "change_item", "change_time")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, change_item, split_date(cast(change_time as String)))))"
      , is_super_filter = false
    )
    , args_company_job("company_account_with_bank", Seq.empty
      , rowkey_udf = "company_id"
      , is_super_filter = false
    )

    , args_company_job("wenshu_detail_v2", Seq("case_no", "title")
      , rowkey_udf = "md5(cleanup(concat_ws('', case_no, title)))"
      , is_super_filter = false
      , where = " is_json_str(defendant_info) and is_json_str(plaintiff_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )
    , args_company_job("company_employment", Seq("company_id", "url_path")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, url_path)))"
      , is_super_filter = false
    )

    , args_company_job("company_wechat", Seq("company_id", "public_num")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, public_num)))"
      , is_super_filter = false
    )

    , args_company_job("company_bid", Seq("title", "link", "publish_time")
      , rowkey_udf = "md5(cleanup(concat_ws('', title, link, split_date(cast(publish_time as String)))))"
      , is_super_filter = false
      , where = " is_json_str(purchaser_info) and is_json_str(supplier_info)"
      , explode_args = Seq(
        explode_args("purchaser_info", "$.keyno", "purchaser_info_id_explode")
        , explode_args("supplier_info", "$.keyno", "supplier_info_id_explode")
      )
    )

    , args_company_job("company_annual_report", Seq("company_id", "report_year")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, report_year)))"
      , id_user_defined_rowkey = true
      , is_super_filter = false
    )

    , args_company_job("company_annual_report_out_investment", Seq("main_id", "out_investment_name")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, out_investment_name))) )"
      , is_super_filter = false
    )

    , args_company_job("company_annual_report_out_guarantee", Seq("main_id", "creditor", "obligor")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, creditor, obligor))) )"
      , is_super_filter = false
    )

    , args_company_job("company_annual_report_change", Seq("main_id", "change_item", "change_time")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, change_item, split_date(cast(change_time as String))))) )"
      , is_super_filter = false
    )

    , args_company_job("company_annual_report_equity_change", Seq("main_id", "change_time")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, split_date(cast(change_time as String))))) )"
      , is_super_filter = false
    )
    , args_company_job("company_annual_report_holder", Seq("main_id", "investor_name")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, investor_name))) )"
      , is_super_filter = false
    )

    , args_company_job("company_annual_report_webinfo", Seq("main_id", "website")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id, website))) )"
      , is_super_filter = false
    )

    , args_company_job("company_annual_report_social_security", Seq("main_id")
      , rowkey_udf = "concat_ws('_', main_id, md5(cleanup(concat_ws('',main_id))) )"
      , is_super_filter = false
    )
//融资
    , args_company_job("accounts_receivablae", Seq("company_name", "notice_date", "pledgee_info", "assignee_info", "deadline")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, split_date(cast(notice_date as String)), get_text_from_json(pledgee_info, 'pledgee'), get_text_from_json(assignee_info, 'assignee'), deadline)))"
      , is_super_filter = false
    )

    , args_company_job("dcm_registration_limit", Seq("company_id", "fileno", "bond_lassify", "start_date")
        , rowkey_udf = "md5(cleanup(concat_ws('', company_id, fileno, bond_lassify, split_date(cast(start_date as String)))))"
        , is_super_filter = false
    )

    , args_company_job("bond_financing", Seq("company_id", "abbreviation", "symbol")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, abbreviation, symbol)))"
      , is_super_filter = false
    )


    , args_company_job("overseas_bond_financing", Seq("company_id", "bond_simple_name", "issue_date")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, bond_simple_name, split_date(cast(issue_date as String)))))"
      , is_super_filter = false
    )

    , args_company_job("bank_loan", Seq("company_id", "creditor", "amount_financed", "start_date")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, creditor, amount_financed, split_date(cast(start_date as String)))))"
      , is_super_filter = false
    )

    , args_company_job("credit_line", Seq("company_id", "end_date", "discloure_date", "credit_line")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, split_date(cast(end_date as String)), split_date(cast(discloure_date as String)), credit_line)))"
      , is_super_filter = false
    )


    , args_company_job("lease_financing", Seq("company_id", "leaser_info", "equity", "start_date")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, get_text_from_json(leaser_info, 'company_name'), equity, split_date(cast(start_date as String)))))"
      , is_super_filter = false
    )

    , args_company_job("trust_financing", Seq("company_id", "consignee_name_list", "notice_date", "start_date")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, split_date(cast(notice_date as String)), get_text_from_json(consignee_name_list, 'company_name'), split_date(cast(start_date as String)))))"
      , is_super_filter = false
    )

    , args_company_job("other_financing", Seq("company_id", "financing_amount", "declare_date")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, financing_amount, split_date(cast(declare_date as String)))))"
      , is_super_filter = false
    )

    , args_company_job("litigation_mediation", Seq("case_no", "filing_date")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no,split_date(cast(filing_date as String)) )))"
      , is_super_filter = false
      , where = "is_json_str(litigant_info) and is_json_str(defendant_info) and is_json_str(plaintiff_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )


    , args_company_job("construction_qualification", Seq("company_id", "cert_type", "cert_id", "cert_name")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, cert_type, cert_id, cert_name)))"
      , is_super_filter = false
    )

    , args_company_job("construction_person", Seq("company_id", "person_name", "zczy_name", "seal_code")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_id, person_name, zczy_name, seal_code)))"
      , is_super_filter = false
    )

    , args_company_job("construction_project", Seq("company_name", "prj_name", "prj_num")
      , rowkey_udf = "md5(cleanup(concat_ws('', company_name, prj_name, prj_num)))"
      , is_super_filter = false
    )
  )

  def get_args_company_job(tn: String): args_company_job = {
    tab_md5_fields.find(p => tn.equals(p.tableName)).getOrElse(throw new NullPointerException("tn is not fount"))
  }
}
