package com.winhc.bigdata.spark.ng.monitor

import com.winhc.bigdata.spark.config.EsConfig
import com.winhc.bigdata.spark.jobs.dynamic.CompanyDynamicHandleUtils
import com.winhc.bigdata.spark.jobs.monitor.CompanyMonitorHandle
import com.winhc.bigdata.spark.udf.BaseFunc
import com.winhc.bigdata.spark.utils.BaseUtil.isWindows
import com.winhc.bigdata.spark.utils.ReflectUtils.getClazz
import com.winhc.bigdata.spark.utils.{AsyncExtract, LoggingUtils, SparkUtils}
import org.apache.commons.lang3.StringUtils
import org.apache.spark.internal.Logging
import org.apache.spark.sql.types.{DoubleType, StringType}
import org.apache.spark.sql.{Row, SparkSession}

import scala.annotation.meta.getter
import scala.collection.immutable.ListMap
import scala.collection.mutable

/**
 * @Author: π
 * @Date: 2021/9/9
 * @Description: 企业财产监控v8版本
 */
object CompanyMonitorV2 {
  val targetTab = "winhc_ng.ads_company_monitor"

  case class CompanyMonitorUtil(s: SparkSession,
                                project: String, //表所在工程名
                                incr: Boolean //是否增量
                               ) extends LoggingUtils with Logging with BaseFunc {
    @(transient@getter) val spark: SparkSession = s

    private lazy val org_tab = if (incr) "winhc_ng.bds_change_extract" else "winhc_ng.bds_change_extract_all_v2"
    private val ds = getLastPartitionsOrElse(org_tab, "0")
    private val ads_judicial_case_relation_case_amt = "winhc_ng.ads_judicial_case_relation_case_amt"

    def calc(tableName: String, needMoney: String): Unit = {
      val clazz = getClazz[CompanyMonitorHandleV2](s"com.winhc.bigdata.spark.ng.monitor.table.$tableName", incr)
      val conditional = clazz.get_conditional_filter()
      val filter = clazz.filter
      val flat_map = clazz.flat_map
      val tn = tableName

      val rdd = sql(
        s"""
           |SELECT  *
           |FROM    $org_tab
           |WHERE   ds = '$ds'
           |AND     tn = '$tn'
           |$conditional
           |""".stripMargin)
        .rdd.map(r => {
        val value = r.getAs[String]("change_fields")
        val change_fields: Seq[String] = if (StringUtils.isEmpty(value)) Seq.empty else value.split(",")
        ChangeExtract(rowkey = r.getAs("rowkey")
          , company_id = r.getAs("company_id")
          , company_name = null
          , tn = r.getAs("table_name")
          , update_type = r.getAs("update_type")
          , old_data = r.getAs("old_data")
          , new_data = r.getAs("new_data")
          , change_fields = change_fields
          , biz_date = r.getAs("biz_date")
          , update_time = r.getAs("update_time")
        )
      }).filter(r => {
        if (filter == null) {
          true
        } else {
          filter(r.update_type, r.biz_date, r.change_fields, r.old_data, r.new_data)
        }
      }).flatMap(flat_map)
        .map(_.format())
        .filter(_ != null)

      val schema = getSchema(ListMap(
        "id" -> StringType
        , "entity_info" -> StringType
        , "dimension_type" -> StringType
        , "flow_type" -> StringType
        , "rta_desc" -> StringType
        , "change_time" -> StringType
        , "biz_id" -> StringType
        , "info_risk_level" -> StringType
        , "type" -> StringType
        , "create_time" -> StringType
        , "amt" -> DoubleType
        , "update_type" -> StringType
        , "deleted" -> StringType
      ))

      spark.createDataFrame(rdd.map(_.to_row()), schema)
        .createOrReplaceTempView(s"company_monitor_tmp1_$tableName")

      needMoney match {
        case "0" => {
          sql(
            s"""
               |INSERT ${if (isWindows) "INTO" else "OVERWRITE"} TABLE $targetTab PARTITION(ds='$ds',tn='$tableName')
               |SELECT  id
               |        , entity_info
               |        , dimension_type
               |        , flow_type
               |        , rta_desc
               |        , change_time
               |        , biz_id
               |        , info_risk_level
               |        , type
               |        , create_time
               |        , amt
               |        , update_type
               |        , deleted
               |FROM
               |    company_monitor_tmp1_$tableName
               |WHERE id IS NOT NULL
               |""".stripMargin)
        }
        case "1" => {
          sql(
            s"""
               |INSERT ${if (isWindows) "INTO" else "OVERWRITE"} TABLE $targetTab PARTITION(ds='$ds',tn='$tableName')
               |SELECT  id
               |        , entity_info
               |        , dimension_type
               |        , flow_type
               |        , rta_desc
               |        , change_time
               |        , biz_id
               |        , info_risk_level
               |        , type
               |        , create_time
               |        , case_amt
               |        , update_type
               |        , deleted
               |FROM
               |    (
               |        SELECT a.*, b.case_amt
               |        FROM  company_monitor_tmp1_$tableName a
               |        LEFT JOIN $ads_judicial_case_relation_case_amt b  ON a.biz_id = b.detail_id and b.tn = '$tableName'
               |    )
               |WHERE id IS NOT NULL
               |""".stripMargin)
        }
      }
    }
  }

  private val startArgs = Seq(
    Args(tableName = "wenshu_detail_v2")
    , Args(tableName = "company_dishonest_info", needMoney = "1") //todo 金额提取
    //, Args(tableName = "company_zxr")
    , Args(tableName = "company_zxr_restrict", needMoney = "1") //todo 金额提取
    , Args(tableName = "company_court_open_announcement")
    , Args(tableName = "company_equity_info")
    , Args(tableName = "company_land_mortgage")
    , Args(tableName = "company_land_announcement")
    , Args(tableName = "company_finance")
    , Args(tableName = "bankruptcy_open_case")
    , Args(tableName = "company_bid") //todo 待处理
    , Args(tableName = "company_mortgage_info")
    , Args(tableName = "company_tm")
    , Args(tableName = "company_patent")
    , Args(tableName = "company_copyright_reg")
    , Args(tableName = "company_copyright_works")
    , Args(tableName = "company_holder")
    //, Args(tableName = "company", bName = 1)
    , Args(tableName = "auction_tracking")
    , Args(tableName = "increase_registered_capital_info")
    , Args(tableName = "zxr_evaluate")
    , Args(tableName = "zxr_evaluate_results")
    , Args(tableName = "company_license")
    //, Args(tableName = "company_judicial_assistance")

  )

  private case class Args(project: String = "winhc_ng"
                          , tableName: String
                          , needMoney: String = "0")

  def main(args: Array[String]): Unit = {

    if (args.length != 3) {
      println(
        s"""
           |Please enter the legal parameters !
           |<project> <tableNames> <incr>
           |""".stripMargin)
      sys.exit(-99)
    }

    val Array(project, tableNames, incr) = args

    println(
      s"""
         |project: $project
         |tableNames: $tableNames
         |incr: $incr
         |""".stripMargin)

    val config = EsConfig.getEsConfigMap ++ mutable.Map(
      "spark.hadoop.odps.project.name" -> project,
      "spark.hadoop.odps.spark.local.partition.amt" -> "1000"
    )
    val spark = SparkUtils.InitEnv("CompanyMonitorV2", config)
    val cd = CompanyMonitorUtil(spark, project, if ("incr".equals(incr)) true else false)

    var start = startArgs
    if (!tableNames.equals("all")) {
      val set = tableNames.split(",").toSet
      start = start.filter(a => set.contains(a.tableName))
    }

    val a = start.map(e => (e.tableName, () => {
      cd.calc(e.tableName, e.needMoney) //通用处理
      true
    }))

    AsyncExtract.startAndWait(spark, a)
    spark.stop()
  }
}
