package com.winhc.bigdata.spark.ng.monitor.table

import com.winhc.bigdata.spark.implicits.MapHelper._
import com.winhc.bigdata.spark.ng.monitor._
import com.winhc.bigdata.spark.utils.BaseUtil
import org.apache.commons.lang3.StringUtils

import scala.collection.mutable

/**
 * @Date: 2020/9/13 11:44
 * @Description: 在外持有股权被冻结
 *               有股东持有的股权被冻结
 *               有股权解除冻结
 *               有股东持有的股权解除冻结
 */
case class company_judicial_assistance(is_inc: Boolean) extends AbstractDailyHandle {


  override protected def get_money(new_map: Map[String, String]): Double = {
    BaseUtil.amt_div(processMoney(new_map("equity_amount")), "1")
  }

  override def getEntityInfo(new_data: Map[String, String]): Seq[EntityInfo] = {
    Seq.empty[EntityInfo]
  }

  override def flat_map: (ChangeExtract) => Seq[CompanyMonitorRecord] = (change_extract: ChangeExtract) => {
    var list: mutable.Seq[CompanyMonitorRecord] = mutable.Seq.empty

    val tn = change_extract.tn
    val update_type = change_extract.update_type
    val new_data = change_extract.new_data
    val biz_date = change_extract.biz_date
    val rowkey = change_extract.rowkey
    val update_time = change_extract.update_time

    if (StringUtils.isNotBlank(new_data.getOrEmptyStr("fz_execute_order_num"))) {
      //冻结信息
      val `type1` = "28"
      val args1 = CompanyMonitorMappings.get_args(`type1`)
      list = list :+ CompanyMonitorRecord(
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type1`)
        , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("executed_person_id"), name = new_data.getOrEmptyStr("executed_person"), type_id = `type1`))
        , dimension_type = args1.dimension_type
        , flow_type = args1.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args1.info_risk_level
        , `type` = `type1`
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
      val `type2` = "29"
      val args2 = CompanyMonitorMappings.get_args(`type2`)
      list = list :+ CompanyMonitorRecord(
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type2`)
        , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("company_id"), name = new_data.getOrEmptyStr("company_name"), type_id = `type2`))
        , dimension_type = args2.dimension_type
        , flow_type = args2.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args2.info_risk_level
        , `type` = `type2`
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
    } else if (StringUtils.isNotBlank(new_data.getOrEmptyStr("lf_execute_order_num"))) {
      //解冻信息
      val `type3` = "30"
      val args3 = CompanyMonitorMappings.get_args(`type3`)
      list = list :+ CompanyMonitorRecord(
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type3`)
        , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("executed_person_id"), name = new_data.getOrEmptyStr("executed_person"), type_id = `type3`))
        , dimension_type = args3.dimension_type
        , flow_type = args3.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args3.info_risk_level
        , `type` = `type3`
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
      val `type4` = "31"
      val args4 = CompanyMonitorMappings.get_args(`type4`)
      list = list :+ CompanyMonitorRecord(
        id = CompanyMonitorUtils.generateId(rowkey, biz_date, tn, `type4`)
        , entity_info = Seq(EntityInfo(keyno = new_data.getOrEmptyStr("company_id"), name = new_data.getOrEmptyStr("company_name"), type_id = `type4`))
        , dimension_type = args4.dimension_type
        , flow_type = args4.flow_type
        , rta_desc = ""
        , change_time = biz_date
        , biz_id = rowkey
        , info_risk_level = args4.info_risk_level
        , `type` = `type4`
        , create_time = update_time
        , amt = get_money(new_data)
        , update_type = update_type
        , deleted = get_deleted(new_data)
      )
    }
    list
  }
}
